﻿# This is the options file for Builders' Mind, open-sourced for personal use only.  Please do not redistribute modified code unless you have permission from the author.

init -1:
    python hide:

        ## Should we enable the use of developer tools? This should be
        ## set to False before the game is released, so the user can't
        ## cheat using developer tools.

        config.developer = False
        
        ## These control the width and height of the screen.

        config.screen_width = 640
        config.screen_height = 480

        ## This controls the title of the window, when Ren'Py is
        ## running in a window.

        config.window_title = u"Builders' Mind"

        library.translations["Start Game"] = "Start" 
        library.translations["Continue Game"] = "Continue" 
        library.translations["Preferences"] = "Options" 
        library.translations["Begin Skipping"] = "Skip Mode" 

    # This lets us disable the file pager. (So we only have one
    # page of files.) 
    #    library.disable_file_pager = True
        
        ## We then want to call a theme function. themes.roundrect is
        ## a theme that features the use of rounded rectangles. It's
        ## the only theme we currently support.
        ##
        ## The theme function takes a number of parameters that can
        ## customize the color scheme.
        theme.roundrect(

            ## The color of an idle widget face.
            widget = ("#8699a7", "#ffffff"),
            
            ## The color of a focused widget face.
            widget_hover = ("#9eb1ad", "#ffffff"),

            ## The color of the text in a widget.
            widget_text = "#000000",#"#dcdfd6",

            ## The color of the text in a selected widget. (For
            ## example, the current value of a preference.)
            widget_selected = "#ffffff",

            ## The color of a disabled widget face. 
            disabled = ("#919994", "#404040"),

            ## The color of disabled widget text.
            disabled_text = "#B6BFB9",

            ## The color of informational labels.
            label = "#ffffff",

            ## The color of a frame containing widgets.
            frame = "#6f7571",

            ## If this is True, in-game menus are placed in the center
            ## the screen. If False, they are placed inside a window
            ## at the bottom of the screen.
            button_menu = True,

            ## If this is True, the in-game window is rounded. If False,
            ## the in-game window is square.
            rounded_window = False,
            
            ## The background of the main menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            mm_root = "titlescreen.jpg",

            ## The background of the game menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            gm_root = "titlescreen.jpg",

            ## And we're done with the theme. The theme will customize
            ## various styles, so if we want to change them, we should
            ## do so below.            
            )
            
        #########################################
        ## These settings let you customize the window containing the
        ## dialogue and narration, by replacing it with an image.

        ## The background of the window. In a Frame, the two numbers
        ## are the size of the left/right and top/bottom borders,
        ## respectively.

        style.window.background = Solid((255, 255, 255, 255))
        
        ## Margin is space surrounding the window, where the background
        ## is not drawn.

        # style.window.left_margin = 12
        # style.window.right_margin = 12
        # style.window.top_margin = 12
        # style.window.bottom_margin = 12
        
        ## Padding is space inside the window, where the background is
        ## drawn.

        # style.window.left_padding = 6
        # style.window.right_padding = 6
        # style.window.top_padding = 6
        # style.window.bottom_padding = 6

        ## This is the minimum height of the window, including the margins
        ## and padding.

        # style.window.yminimum = 250


        #########################################
        ## This lets you change the placement of the main menu.
        
        ## The way placement works is that we find an anchor point
        ## inside a displayable, and a position (pos) point on the
        ## screen. We then place the displayable so the two points are
        ## at the same place.

        ## An anchor/pos can be given as an integer or a floating point
        ## number. If an integer, the number is interpreted as a number
        ## of pixels from the upper-left corner. If a floating point,
        ## the number is interpreted as a fraction of the size of the
        ## displayable or screen.

        # style.mm_menu_frame.xpos = 0.5
        # style.mm_menu_frame.xanchor = 0.5
        # style.mm_menu_frame.ypos = 0.75
        # style.mm_menu_frame.yanchor = 0.5


        #########################################
        ## These let you customize the default font used for text in Ren'Py.

        ## The file containing the default font.

        #style.default.font = "angltrr.ttf"  Decided to use default font to save space

        style.default.color = "000000"

        ## The default size of text.

        style.default.size = 22

        ## Note that these only change the size of some of the text. Other
        ## buttons have their own styles.


        #########################################
        ## These settings let you change some of the sounds that are used by
        ## Ren'Py.

        ## Set this to False if the game does not have any sound effects.

        config.has_sound = True

        ## Set this to False if the game does not have any music.

        config.has_music = True

        ## Set this to False if the game does not have voicing.

        config.has_voice = True

        ## Sounds that are used when button and imagemaps are clicked.

        # style.button.activate_sound = "click.wav"
        # style.imagemap.activate_sound = "click.wav"

        ## Sounds that are used when entering and exiting the game menu.

        # config.enter_sound = "click.wav"
        # config.exit_sound = "click.wav"

        ## A sample sound that can be played to check the sound volume.

        # config.sample_sound = "click.wav"

        ## Music that is played while the user is at the main menu.

        # config.main_menu_music = "main_menu_theme.ogg"

        #########################################
        ## Transitions.

        ## Used when entering the game menu from the game.
        config.enter_transition = None

        ## Used when exiting the game menu to the game.
        config.exit_transition = None

        ## Used between screens of the game menu.
        config.intra_transition = None

        ## Used when entering the game menu from the main menu.
        config.main_game_transition = None

        ## Used when returning to the main menu from the game.
        config.game_main_transition = None

        ## Used when entering the main menu from the splashscreen.
        config.end_splash_transition = None

        ## Used when entering the main menu after the game has ended.
        config.end_game_transition = None
        
        
        #########################################
        ## Default values of Preferences.

        ## Note: These options are only evaluated the first time a
        ## game is run. To have them run a second time, delete
        ## game/saves/persistent
        
        ## Should we start in fullscreen mode?
        config.default_fullscreen = False

        ## The default text speed in characters per second. 0 is infinite.
        config.default_text_cps = 80
        
        ## image declarations
init:
    image black = Solid((0, 0, 0, 255))
    image white = Solid((255, 255, 255, 255))
    image dafoollogobase = "dafoollogo.jpg"
    image dafoollogooverlay = "dafoollogo2_640.png"
    $ dafoollogobasegray = im.Sepia("dafoollogo.jpg")
    image dafoollogoalpha = im.Alpha(dafoollogobasegray, 0.5)
    
    $ narrator = Character(None, color="#000000", window_yminimum=20)
    $ bert = Character('Bert', color="#000000")
    $ hiraya = Character('Hiraya', color="#000000")
    $ phineas = Character('Phineas', color="#000000")
    $ ashley = Character('Ashley', color="#000000")
    $ philip = Character('Philip', color="#000000")
    $ mayumipre = Character('???', color="#000000")
    $ mayumi = Character('Mayumi', color="#000000")
    $ rohit = Character('Rohit', color="#000000")
    $ paulo = Character('Paulo', color="#000000")    
    image port = "port.jpg"
    image university = "university.jpg"
    image machinery = "machinery.jpg"
    image gears = im.Scale("gears.png", 424,424)
    image gears2 = "gears.png"
    $ shiftwaves = im.Scale("shiftwaves.png", 640,480)
    $ shiftwaves2 = im.Scale("shiftwaves.png", 644, 484)
    image shiftingwaves = Animation(shiftwaves, 0.5, shiftwaves2, 0.5)
    $ universitydark = im.Sepia("university.jpg")
    image universitydusk = im.Alpha(universitydark, 0.5)
    image hirayahouse = "hirayahouse.jpg"
    image vicinity = "vicinity.jpg"
    image philiphouse = "philiphouse.jpg"
    image crate = "crate.jpg"
    image signage = "signage.jpg"
    
    image sprite hirayablushing = im.Composite((195, 160), (0, 0), "hirayasadhappy.jpg", (0, 0), "hirayablushing.png")
    image sprite hirayadetermined = "hirayadetermined.jpg"
    image sprite hirayahappy = "hirayahappy.jpg"
    image sprite hirayahappyblushing = im.Composite((195, 160), (0, 0), "hirayahappy.jpg", (0, 0), "hirayablushing.png")
    image sprite hirayasad = "hirayasad.jpg"
    image sprite hirayashocked = "hirayashocked.jpg"
    image sprite hirayasadhappy = "hirayasadhappy.jpg"
    image sprite hirayashockedblush = im.Composite((195, 160), (0, 0), "hirayashocked.jpg", (0, 0), "hirayablushing.png")
    
    image sprite phineasnormal = "phineasnormal.jpg"
    image sprite phineaslaugh = "phineaslaugh.jpg"
    image sprite phineasangry = "phineasangry.jpg"
    
    image sprite bertmad = "bertmad.jpg"
    image sprite bertnormal = "bertnormal.jpg"
    image sprite bertresigned = "bertresigned.jpg"
    
    image sprite ashleynormal = "ashleynormal.jpg"
    image sprite ashleysmiling = "ashleysmiling.jpg"
    image sprite ashleyfrowning = "ashleyfrowning.jpg"
    
    image sprite mayumicheerful = "mayumicheerful.jpg"
    image mayumicheerful2 = "mayumicheerful.jpg"
    image sprite mayumishy = "mayumishy.jpg"
    image mayumishy2 = "mayumishy.jpg"
    image sprite mayumiserious = "mayumiserious.jpg"
    
    image sprite philipblushing = im.Composite((207, 240), (0, 0), "philipavoid.jpg", (0, 0), "philipblushing.png")
    image sprite philipblushingfriendly = im.Composite((207, 240), (0, 0), "philipfriendly.jpg", (0, 0), "philipblushing.png")
    image philipblushingfriendly2 = im.Composite((207, 240), (0, 0), "philipfriendly.jpg", (0, 0), "philipblushing.png")    
    image sprite philipcool = "philipcool.jpg"
    image sprite philipfriendly = "philipfriendly.jpg"
    image philipfriendly2 = "philipfriendly.jpg"
    image sprite philipshocked = "philipshocked.jpg"
    image sprite philipavoid = "philipavoid.jpg"
    
    image sprite rohitcheerful = "rohitcheerful.jpg"
    image rohitcheerful2 = "rohitcheerful.jpg"
    image sprite rohitdepressed = "rohitdepressed.jpg"
    
    image sprite pauloworried = "pauloworried.jpg"
    image sprite paulohappy = "paulohappy.jpg"
    image paulohappy2 = "paulohappy.jpg"
    
    $ poshiraya = Position(xpos=222, xanchor=0, ypos=50, yanchor=0)
    $ posphineas = Position(xpos=200, xanchor=0, ypos=10, yanchor=0)
    $ posphilip = Position(xpos=216, xanchor=0, ypos=10, yanchor=0)
    $ posphilip2 = Position(xpos=423, xanchor=0, ypos=10, yanchor=0)
    $ posashley = Position(xpos=203, xanchor=0, ypos=10, yanchor=0)
    $ posmayumi = Position(xpos=234, xanchor=0, ypos=30, yanchor=0)
    $ posmayumi2 = Position(xpos=30, xanchor=0, ypos=30, yanchor=0)
    $ posbert = Position(xpos=182, xanchor=0, ypos=10, yanchor=0)    
    $ posrohit = Position(xpos=220, xanchor=0, ypos=10, yanchor=0)
    $ posrohit2 = Position(xpos=10, xanchor=0, ypos=10, yanchor=0)     
    $ pospaulo = Position(xpos=214, xanchor=0, ypos=50, yanchor=0)
    $ pospaulo2 = Position(xpos=407, xanchor=0, ypos=50, yanchor=0)     
    
    $ poscrate = Position(xpos=208, xanchor=0, ypos=10, yanchor=0) 
    $ possignage = Position(xpos=144, xanchor=0, ypos=10, yanchor=0) 
    
label splashscreen:

    $ renpy.music.play ("dafoolintroshort.ogg", loop=False)
    scene white
    show dafoollogobase 
    with Dissolve(0.2)
    with Pause (1.0)
    hide dafoollogobase
    show dafoollogoalpha 
    show dafoollogooverlay at center
    with Dissolve(3.0)
    $ renpy.music.stop(fadeout=2.0)
    with Pause (2.0)
    scene black
    with Dissolve(0.5)
    return
        


## This section contains information about how to build your project into
## distribution files.
init python:

    ## The name that's used for directories and archive files. For example, if
    ## this is 'mygame-1.0', the windows distribution will be in the
    ## directory 'mygame-1.0-win', in the 'mygame-1.0-win.zip' file.
    build.directory_name = "BuildersMind-1.0-6.99.12"

    ## The name that's uses for executables - the program that users will run
    ## to start the game. For example, if this is 'mygame', then on Windows,
    ## users can click 'mygame.exe' to start the game.
    build.executable_name = "BuildersMind"

    ## If True, Ren'Py will include update information into packages. This
    ## allows the updater to run.
    build.include_update = False

    ## File patterns:
    ##
    ## The following functions take file patterns. File patterns are case-
    ## insensitive, and matched against the path relative to the base
    ## directory, with and without a leading /. If multiple patterns match,
    ## the first is used.
    ##
    ##
    ## In a pattern:
    ##
    ## /
    ##     Is the directory separator.
    ## *
    ##     Matches all characters, except the directory separator.
    ## **
    ##     Matches all characters, including the directory separator.
    ##
    ## For example:
    ##
    ## *.txt
    ##     Matches txt files in the base directory.
    ## game/**.ogg
    ##     Matches ogg files in the game directory or any of its subdirectories.
    ## **.psd
    ##    Matches psd files anywhere in the project.

    ## Classify files as None to exclude them from the built distributions.

    build.classify('**~', None)
    build.classify('**.bak', None)
    build.classify('**/.**', None)
    build.classify('**/#**', None)
    build.classify('**/thumbs.db', None)

    ## To archive files, classify them as 'archive'.

    build.classify('game/images/**.png', 'archive')
    build.classify('game/images/**.jpg', 'archive')
    build.classify('game/**.ogg', 'archive')

    ## Files matching documentation patterns are duplicated in a mac app
    ## build, so they appear in both the app and the zip file.

    build.documentation('*.html')
    build.documentation('*.txt')
    
